==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/da.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Personal activity feed for %s" : "Personlige aktiviteter for %s ",
    "Your feed URL is invalid" : "Din feed-URL er ugyldg",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "Activities" : "Aktiviteter",
    "Error loading activities" : "Fejl ved indlæsning af aktiviteter",
    "No activities" : "Ingen aktiviteter",
    "This stream will show events like additions, changes & shares" : "Dette område vil vise begivenheder som tilføjelser, ændringer & delinger",
    "There are no events for this filter" : "Der ingen aktiviteter for dette filter",
    "Activity notification" : "Notifikation om aktivitet",
    "All Activities" : "Alle aktiviteter",
    "Activities by you" : "Dine aktiviteter",
    "Activities by others" : "Andres aktiviteter",
    "\"remote user\"" : "\"ekstern bruger\"",
    "in %s" : "i %s",
    "%s and %s" : "%s og %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s og <strong %s>%n mere</strong>","%s og <strong %s>%n flere</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s og %n mere","%s og %n flere"],
    "Hello %s," : "Hej %s,",
    "You are receiving this email because the following things happened at %s" : "Du modtager denne email fordi følgende ting er opstået ved %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og %n flere","* og %n flere"],
    "Notifications" : "Beskeder",
    "List your own actions in the stream" : "Få vist dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Giv meddelelse om egne handlinger via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Du skal angive din e-mailadresse før du kan modtage notifikationer via e-mail.",
    "Send emails:" : "Send e-mails:",
    "Hourly" : "Hver time",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Activity feed" : "Feed med aktiviteter",
    "Enable RSS feed" : "Aktiverer RSS feed",
    "No activity yet" : "Ingen aktiviteter endnu",
    "No more events to load" : "Der er Ikke flere aktiviteter som kan indlæses",
    "Files" : "Filer",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s og <strong class=\"has-tooltip\" title=\"%s\">%n mere</strong>","%s og <strong class=\"has-tooltip\" title=\"%s\">%n flere</strong>"]
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/da.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Personal activity feed for %s" : "Personlige aktiviteter for %s ",
    "Your feed URL is invalid" : "Din feed-URL er ugyldg",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "Activities" : "Aktiviteter",
    "Error loading activities" : "Fejl ved indlæsning af aktiviteter",
    "No activities" : "Ingen aktiviteter",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Dette område vil vise begivenheder som tilføjelser, ændringer & delinger",
    "There are no events for this filter" : "Der ingen aktiviteter for dette filter",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "\"remote user\"" : "\"ekstern bruger\"",
    "Activity notification" : "Notifikation om aktivitet",
    "All Activities" : "Alle aktiviteter",
    "Activities by you" : "Dine aktiviteter",
    "Activities by others" : "Andres aktiviteter",
    "%s and %s" : "%s og %s",
    "Hello %s," : "Hej %s,",
    "You are receiving this email because the following things happened at %s" : "Du modtager denne email fordi følgende ting er opstået ved %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og %n flere","* og %n flere"],
    "List your own actions in the stream" : "Få vist dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Giv meddelelse om egne handlinger via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Du skal angive din e-mailadresse før du kan modtage notifikationer via e-mail.",
    "Send emails:" : "Send e-mails:",
    "Hourly" : "Hver time",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Activity feed" : "Feed med aktiviteter",
    "Enable RSS feed" : "Aktiverer RSS feed",
    "No activity yet" : "Ingen aktiviteter endnu",
    "No more events to load" : "Der er Ikke flere aktiviteter som kan indlæses",
    "Files" : "Filer"
},
"nplurals=2; plural=(n != 1);");
